@@ -19,12 +19,11 @@
 
 #include "tooltip.h"
 
-#include <kglobal.h>
-#include <kglobalsettings.h>
-
 #include <qevent.h>
 #include <qtextdocument.h>
 #include <qtooltip.h>
+#include <QApplication>
+#include <QDesktopWidget>
 
 
 namespace Cervisia
@@ -58,7 +57,7 @@ bool ToolTip::eventFilter(QObject* watched, QEvent* event)
             text = truncateLines(text,
                                  QToolTip::font(),
                                  helpEvent->globalPos(),
-                                 KGlobalSettings::desktopGeometry(parentWidget));
+                                 qApp->desktop()->availableGeometry(parentWidget));
             QToolTip::showText(helpEvent->globalPos(), text, parentWidget, rect);
         }
 
@@ -69,7 +68,7 @@ bool ToolTip::eventFilter(QObject* watched, QEvent* event)
 }
 
 
-// Primtive routine to truncate the text. size.width() is ignored, only
+// Primitive routine to truncate the text. size.width() is ignored, only
 // size.height() is used at the moment to keep it fast. It doesn't work
 // correct if text lines have different heights.
 QString truncateLines(const QString&      text,
@@ -123,4 +122,3 @@ QString truncateLines(const QString& text,
 } // namespace Cervisia
 
 
-#include "tooltip.moc"
